#!/bin/bash

########################################################################
# SET ENVIRONMENT FOR EPAGES
########################################################################

check_variables () {
  unset UNSET
  for i in $@ ; do
    if [ -z "`eval echo '$'$i`" ] ; then
      UNSET="$UNSET $i"
    fi
  done
  if [ -n "$UNSET" ] ; then
    echo "Following required variables must be set:"
    echo " $UNSET"
    echo "You might do this by running:"
    echo "  . /etc/default/epages6"
    exit 1
  fi
}

check_variables EPAGES_PROJECT EPAGES_PERL EPAGES_CARTRIDGES EPAGES_CONFIG

EPAGES_INITD=/etc/init.d/$EPAGES_PROJECT

if [ ! -x $EPAGES_INITD ] ; then
  echo "Can't execute $EPAGES_INITD."
  exit 1
fi

DN="`dirname $0`"
DN=`cd "$DN" ; pwd` || exit 1

PERL="$EPAGES_PERL/bin/perl"
if [ "x`\"$PERL\" -e 'print 1'`" != "x1" ] ; then
  echo "Program perl not found in '$PERL'."
  exit 1
fi

DE_EPAGES="$EPAGES_CARTRIDGES/DE_EPAGES"

INSTALLDB_PL="$DE_EPAGES"/ShopConfiguration/Scripts/installDatabase.pl
for FILE in "$INSTALLDB_PL" ; do
  if [ ! -f "$FILE" ] ; then
    echo "File not found: $FILE"
    exit 1
  fi
done

########################################################################
# SHELL FUNCTIONS
########################################################################

exit_setup()
{
  [ $1 -ne 0 ] && $EPAGES_INITD stop_service
  exit $1
}

########################################################################
# MAIN
########################################################################

echo "Installing epages ASPoolDB."
echo "---------------------------"

"$PERL" "$INSTALLDB_PL" -storename ASPoolDB -type ASPoolDB -nosync || exit_setup $?

$EPAGES_INITD perm admin

echo "-----------------------------"
echo "Installing ASPoolDB finished."

exit_setup 0

########################################################################
# END
########################################################################
