#!/bin/bash

BN=${0##*/}
DN=$(cd $(dirname $0) && pwd)

########################################################################
# usage
########################################################################

usage() {
  ( echo "Usage:"
    echo "  $BN -s epages6 -t epages6.ept [-i]"
    echo "Options:"
    echo "  -s: file to change (e.g.: /etc/default/epages6)"
    echo "  -t: new template file (e.g.: /srv/epages/etc/default/epages6.ept)"
    echo "  -i: edit file to change in place" ) 1>&2
  exit 1
}

[[ $# -eq 0 ]] && usage

unset ETC_DEFAULT DEFAULT_EPT INPLACE
while getopts s:t:i c ; do
  case $c in
    s) ETC_DEFAULT=$OPTARG ;;
    t) DEFAULT_EPT=$OPTARG ;;
    i) INPLACE=1 ;;
    *) usage ;;
  esac
done

[[ -z $ETC_DEFAULT || -z $DEFAULT_EPT ]] && usage
ls "$DEFAULT_EPT" >/dev/null || usage

PATH=$DN:/var/epages:$PATH
type ini-config.sh >/dev/null || exit $?

#-----------------------------------------------------------------------
# ECHO
#-----------------------------------------------------------------------

ECHO () {
  local LINE_NUMBER=$(printf "%3d" $1)
  shift
  echo -e "[${0##*/}:$LINE_NUMBER] $@" 1>&2
}

########################################################################
# execution
########################################################################

TEMP=/tmp/epages/epages-patch
mkdir -m 1777 -p /tmp/epages $TEMP
TMP_DEFAULT=$TEMP/${BN%.sh}.~$$~

# set existing environment

ETC_DEFAULT=$(readlink -f "$ETC_DEFAULT")
ECHO $LINENO "cp -p $DEFAULT_EPT $TMP_DEFAULT"
cp -p "$DEFAULT_EPT" "$TMP_DEFAULT" || exit 1

# update $TMP_DEFAULT

ECHO $LINENO "edit $TMP_DEFAULT"
for variable in $(grep -P '\s*export ' "$ETC_DEFAULT") ; do
  [[ $variable = export ]] && continue
  # don't set variable if neither set in old nor new
  if ! grep -Pq "^\s*$variable\b" "$ETC_DEFAULT" \
    && ! grep -Pq "^\s*$variable\b" "$TMP_DEFAULT" ; then
    continue
  fi
  # get value from old $ETC_DEFAULT
  value=$(ini-config.sh -f "$ETC_DEFAULT" -k $variable -g)
  # and set it in new $TMP_DEFAULT
  ini-config.sh -f "$TMP_DEFAULT" -k $variable -v "$value" -i
done

if [[ -z $INPLACE ]] ; then
  ECHO $LINENO "cat $TMP_DEFAULT"
  cat $TMP_DEFAULT
else
  ECHO $LINENO "cat $TMP_DEFAULT > $ETC_DEFAULT"
  cat $TMP_DEFAULT > "$ETC_DEFAULT"
fi

rm -f $TMP_DEFAULT

exit 0
